Re: [PATCH 1/2] upload-pack: avoid parsing objects during ref advertisement
On Tue, Jan 29, 2013 at 12:10:59AM -0800, Shawn O. Pearce wrote:
Show 9 quoted lines
> > On a repository with 120K refs, the advertisement portion of
> > upload-pack goes from ~3.4s to 3.2s (the failure to speed up
> > more is largely due to the fact that most of these refs are
> > tags, which need dereferenced to find the tag destination
> > anyway).
>
> Why aren't we using the peeled information from the packed-refs file?
> JGit does this and it saves a lot of time on advertisements from a
> well packed repository.
The patch you are replying to is a year old. Since then, I did:
435c833 (upload-pack: use peel_ref for ref advertisements, 2012-10-04)
-Peff